@@ -5,18 +5,25 @@ easymq.api
 Methods that are exposed to the user by default
 """
 
+import atexit
 from typing import Any, Iterable, Union, Tuple, Optional, Callable
 
-from .session import get_current_session
+from .session import AmqpSession
+
+
+_CURRENT_SESSION = AmqpSession()
+
+
+atexit.register(_CURRENT_SESSION.disconnect)
 
 
 # Server connection API
 def connect(*args, auth: Optional[Tuple[Optional[str], Optional[str]]] = (None, None)) -> None:
-    get_current_session().connect(*args, auth=auth or (None,) * 2)
+    _CURRENT_SESSION.connect(*args, auth=auth or (None,) * 2)
 
 
 def disconnect(*args) -> None:
-    get_current_session().disconnect(*args)
+    _CURRENT_SESSION.disconnect(*args)
 
 
 # Publishing API
@@ -24,17 +31,17 @@ def publish(
     message: Any,
     key: Optional[str] = None,
     exchange: Optional[str] = None,
-    block=False,
+    confirm_delivery=False,
 ) -> None:
-    get_current_session().publish(message, key, exchange, block)
+    _CURRENT_SESSION.publish(message, key, exchange, confirm_delivery)
 
 
 def publish_all(
     messages: Iterable[Union[str, Tuple[str, Any]]],
     exchange: Optional[str] = None,
-    block=False,
+    confirm_delivery=False,
 ) -> None:
-    get_current_session().publish_all(messages, exchange, block)
+    _CURRENT_SESSION.publish_all(messages, exchange, confirm_delivery)
 
 
 # Consuming API *implement later
